Enum Elements

pub enum Elements {
    Standard {
        attrs: Vec<Element>,
        element: Element,
    },
    Attribute(Element),
    Global(Element),
    Comment(Element),
}
Elements represent the four possible element types in the YES spec.

Typically the parser is responsible for assembling these variants. See the implemenation for ways to construct a new variant.

Variants



Standard

Fields

attrs: Vec<Element>
element: Element


Attribute(Element)



Global(Element)



Comment(Element)

Implementations

Source

impl Elements

pub fn new_standard(label: String) -> Elements

Constructs a new Elements::Standard with [label] to be identified with later. The initial Elements::Standard::attrs vector is empty.

pub fn new_attribute(label: String) -> Elements

Constructs a new Elements::Attribute with [label] to be identified with later.

pub fn new_global(label: String) -> Elements

Constructs a new Elements::Global with [label] to be identified with later.

pub fn new_comment(message: String) -> Elements

Constructs a new Elements::Comment with a [message].

pub fn copy(other: &Element) -> Element

Returns a copy of the data structure Element.

pub fn upsert_keyval(&mut self, keyval: KeyVal)

Simplifies a call to the data structure Element by pattern matching. See Element::upsert.